@@ -1,4 +1,4 @@
-package SDLx::Controller::Timer;
+package SDLx::Widget::Controller::Timer;
 
 # Implementation of lesson 13 and 14 from http://lazyfoo.net/SDL_tutorials/index.php
 #
